from .types.v1 import datastore_pb2 as _datastore_pb2
from .types.v1 import etl_pb2 as _etl_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetGroupsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetGroupsResponse(_message.Message):
    __slots__ = ("groups",)
    GROUPS_FIELD_NUMBER: _ClassVar[int]
    groups: _containers.RepeatedCompositeFieldContainer[_etl_pb2.ETLGroup]
    def __init__(self, groups: _Optional[_Iterable[_Union[_etl_pb2.ETLGroup, _Mapping]]] = ...) -> None: ...

class GetConnectorsRequest(_message.Message):
    __slots__ = ("hostname",)
    HOSTNAME_FIELD_NUMBER: _ClassVar[int]
    hostname: str
    def __init__(self, hostname: _Optional[str] = ...) -> None: ...

class GetConnectorsResponse(_message.Message):
    __slots__ = ("connectors",)
    CONNECTORS_FIELD_NUMBER: _ClassVar[int]
    connectors: _containers.RepeatedCompositeFieldContainer[_etl_pb2.ETLConnector]
    def __init__(self, connectors: _Optional[_Iterable[_Union[_etl_pb2.ETLConnector, _Mapping]]] = ...) -> None: ...

class GetConnectorByDbNameRequest(_message.Message):
    __slots__ = ("hostname", "db_name")
    HOSTNAME_FIELD_NUMBER: _ClassVar[int]
    DB_NAME_FIELD_NUMBER: _ClassVar[int]
    hostname: str
    db_name: str
    def __init__(self, hostname: _Optional[str] = ..., db_name: _Optional[str] = ...) -> None: ...

class GetConnectorByDbNameResponse(_message.Message):
    __slots__ = ("connector", "datastore")
    CONNECTOR_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_FIELD_NUMBER: _ClassVar[int]
    connector: _etl_pb2.ETLConnector
    datastore: _datastore_pb2.Datastore
    def __init__(self, connector: _Optional[_Union[_etl_pb2.ETLConnector, _Mapping]] = ..., datastore: _Optional[_Union[_datastore_pb2.Datastore, _Mapping]] = ...) -> None: ...

class GetDestinationsRequest(_message.Message):
    __slots__ = ("hostname",)
    HOSTNAME_FIELD_NUMBER: _ClassVar[int]
    hostname: str
    def __init__(self, hostname: _Optional[str] = ...) -> None: ...

class GetDestinationsResponse(_message.Message):
    __slots__ = ("destinations",)
    DESTINATIONS_FIELD_NUMBER: _ClassVar[int]
    destinations: _containers.RepeatedCompositeFieldContainer[_etl_pb2.ETLDestination]
    def __init__(self, destinations: _Optional[_Iterable[_Union[_etl_pb2.ETLDestination, _Mapping]]] = ...) -> None: ...

class GetDestinationByIDRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetDestinationByIDResponse(_message.Message):
    __slots__ = ("destination", "datastore")
    DESTINATION_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_FIELD_NUMBER: _ClassVar[int]
    destination: _etl_pb2.ETLDestination
    datastore: _datastore_pb2.Datastore
    def __init__(self, destination: _Optional[_Union[_etl_pb2.ETLDestination, _Mapping]] = ..., datastore: _Optional[_Union[_datastore_pb2.Datastore, _Mapping]] = ...) -> None: ...

class GetLineageSchemasRequest(_message.Message):
    __slots__ = ("connector_id",)
    CONNECTOR_ID_FIELD_NUMBER: _ClassVar[int]
    connector_id: str
    def __init__(self, connector_id: _Optional[str] = ...) -> None: ...

class GetLineageSchemasResponse(_message.Message):
    __slots__ = ("schemas",)
    SCHEMAS_FIELD_NUMBER: _ClassVar[int]
    schemas: _containers.RepeatedCompositeFieldContainer[_etl_pb2.ETLSchemaLineage]
    def __init__(self, schemas: _Optional[_Iterable[_Union[_etl_pb2.ETLSchemaLineage, _Mapping]]] = ...) -> None: ...

class GetLineageSchemaByNameRequest(_message.Message):
    __slots__ = ("connector_id", "schema_name")
    CONNECTOR_ID_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_NAME_FIELD_NUMBER: _ClassVar[int]
    connector_id: str
    schema_name: str
    def __init__(self, connector_id: _Optional[str] = ..., schema_name: _Optional[str] = ...) -> None: ...

class GetLineageSchemaByNameResponse(_message.Message):
    __slots__ = ("schema",)
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    schema: _etl_pb2.ETLSchemaLineage
    def __init__(self, schema: _Optional[_Union[_etl_pb2.ETLSchemaLineage, _Mapping]] = ...) -> None: ...

class GetLineageTablesRequest(_message.Message):
    __slots__ = ("connector_id",)
    CONNECTOR_ID_FIELD_NUMBER: _ClassVar[int]
    connector_id: str
    def __init__(self, connector_id: _Optional[str] = ...) -> None: ...

class GetLineageTablesResponse(_message.Message):
    __slots__ = ("tables",)
    TABLES_FIELD_NUMBER: _ClassVar[int]
    tables: _containers.RepeatedCompositeFieldContainer[_etl_pb2.ETLTableLineage]
    def __init__(self, tables: _Optional[_Iterable[_Union[_etl_pb2.ETLTableLineage, _Mapping]]] = ...) -> None: ...

class GetLineageTableByNameRequest(_message.Message):
    __slots__ = ("connector_id", "schema_id", "table_name")
    CONNECTOR_ID_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_ID_FIELD_NUMBER: _ClassVar[int]
    TABLE_NAME_FIELD_NUMBER: _ClassVar[int]
    connector_id: str
    schema_id: str
    table_name: str
    def __init__(self, connector_id: _Optional[str] = ..., schema_id: _Optional[str] = ..., table_name: _Optional[str] = ...) -> None: ...

class GetLineageTableByNameResponse(_message.Message):
    __slots__ = ("table",)
    TABLE_FIELD_NUMBER: _ClassVar[int]
    table: _etl_pb2.ETLTableLineage
    def __init__(self, table: _Optional[_Union[_etl_pb2.ETLTableLineage, _Mapping]] = ...) -> None: ...

class GetLineageColumnsRequest(_message.Message):
    __slots__ = ("connector_id",)
    CONNECTOR_ID_FIELD_NUMBER: _ClassVar[int]
    connector_id: str
    def __init__(self, connector_id: _Optional[str] = ...) -> None: ...

class GetLineageColumnsResponse(_message.Message):
    __slots__ = ("columns",)
    COLUMNS_FIELD_NUMBER: _ClassVar[int]
    columns: _containers.RepeatedCompositeFieldContainer[_etl_pb2.ETLColumnLineage]
    def __init__(self, columns: _Optional[_Iterable[_Union[_etl_pb2.ETLColumnLineage, _Mapping]]] = ...) -> None: ...

class GetLineageColumnsByTableRequest(_message.Message):
    __slots__ = ("connector_id", "table_id")
    CONNECTOR_ID_FIELD_NUMBER: _ClassVar[int]
    TABLE_ID_FIELD_NUMBER: _ClassVar[int]
    connector_id: str
    table_id: str
    def __init__(self, connector_id: _Optional[str] = ..., table_id: _Optional[str] = ...) -> None: ...

class GetLineageColumnsByTableResponse(_message.Message):
    __slots__ = ("columns",)
    COLUMNS_FIELD_NUMBER: _ClassVar[int]
    columns: _containers.RepeatedCompositeFieldContainer[_etl_pb2.ETLColumnLineage]
    def __init__(self, columns: _Optional[_Iterable[_Union[_etl_pb2.ETLColumnLineage, _Mapping]]] = ...) -> None: ...



from .types.v1 import connection_pb2 as _connection_pb2
from .types.v1 import organization_pb2 as _organization_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetWorkOsOrgRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetWorkOsOrgResponse(_message.Message):
    __slots__ = ("workos_org", "self_sign_up")
    WORKOS_ORG_FIELD_NUMBER: _ClassVar[int]
    SELF_SIGN_UP_FIELD_NUMBER: _ClassVar[int]
    workos_org: _organization_pb2.Organization
    self_sign_up: bool
    def __init__(self, workos_org: _Optional[_Union[_organization_pb2.Organization, _Mapping]] = ..., self_sign_up: bool = ...) -> None: ...

class UpdateWorkOsOrgRequest(_message.Message):
    __slots__ = ("domains", "self_sign_up")
    DOMAINS_FIELD_NUMBER: _ClassVar[int]
    SELF_SIGN_UP_FIELD_NUMBER: _ClassVar[int]
    domains: _containers.RepeatedScalarFieldContainer[str]
    self_sign_up: bool
    def __init__(self, domains: _Optional[_Iterable[str]] = ..., self_sign_up: bool = ...) -> None: ...

class UpdateWorkOsOrgResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetSsoConnectionsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetSsoConnectionsResponse(_message.Message):
    __slots__ = ("connections",)
    CONNECTIONS_FIELD_NUMBER: _ClassVar[int]
    connections: _containers.RepeatedCompositeFieldContainer[_connection_pb2.Connection]
    def __init__(self, connections: _Optional[_Iterable[_Union[_connection_pb2.Connection, _Mapping]]] = ...) -> None: ...

class DeleteConnectionRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteConnectionResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/integration_kms.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/integration_kms.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import key_pb2 as admin_dot_v1_dot_types_dot_v1_dot_key__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61\x64min/v1/integration_kms.proto\x12\x08\x61\x64min.v1\x1a\x1b\x61\x64min/v1/types/v1/key.proto\"\xd7\x01\n\x1c\x43reateKeyRegistrationRequest\x12!\n\x0c\x63loud_region\x18\x01 \x01(\tR\x0b\x63loudRegion\x12\x15\n\x06key_id\x18\x02 \x01(\tR\x05keyId\x12\x1d\n\nmanaged_by\x18\x03 \x01(\tR\tmanagedBy\x12\x19\n\x08key_type\x18\x04 \x01(\tR\x07keyType\x12\x19\n\x08key_name\x18\x05 \x01(\tR\x07keyName\x12(\n\x10\x63loud_account_id\x18\x06 \x01(\tR\x0e\x63loudAccountId\"I\n\x1d\x43reateKeyRegistrationResponse\x12(\n\x03key\x18\x01 \x01(\x0b\x32\x16.admin.v1.types.v1.KeyR\x03key\":\n\x0eGetKeysRequest\x12(\n\x10\x66ilter_by_status\x18\x01 \x01(\tR\x0e\x66ilterByStatus\"=\n\x0fGetKeysResponse\x12*\n\x04keys\x18\x01 \x03(\x0b\x32\x16.admin.v1.types.v1.KeyR\x04keys\"\x1f\n\rGetKeyRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\":\n\x0eGetKeyResponse\x12(\n\x03key\x18\x01 \x01(\x0b\x32\x16.admin.v1.types.v1.KeyR\x03key\"5\n#DeactivateFieldEncryptionKeyRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"&\n$DeactivateFieldEncryptionKeyResponse2\xf2\x02\n\nKmsService\x12h\n\x15\x43reateKeyRegistration\x12&.admin.v1.CreateKeyRegistrationRequest\x1a\'.admin.v1.CreateKeyRegistrationResponse\x12>\n\x07GetKeys\x12\x18.admin.v1.GetKeysRequest\x1a\x19.admin.v1.GetKeysResponse\x12;\n\x06GetKey\x12\x17.admin.v1.GetKeyRequest\x1a\x18.admin.v1.GetKeyResponse\x12}\n\x1c\x44\x65\x61\x63tivateFieldEncryptionKey\x12-.admin.v1.DeactivateFieldEncryptionKeyRequest\x1a..admin.v1.DeactivateFieldEncryptionKeyResponseB\xa9\x01\n\x0c\x63om.admin.v1B\x13IntegrationKmsProtoP\x01ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.integration_kms_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\023IntegrationKmsProtoP\001ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_CREATEKEYREGISTRATIONREQUEST']._serialized_start=74
  _globals['_CREATEKEYREGISTRATIONREQUEST']._serialized_end=289
  _globals['_CREATEKEYREGISTRATIONRESPONSE']._serialized_start=291
  _globals['_CREATEKEYREGISTRATIONRESPONSE']._serialized_end=364
  _globals['_GETKEYSREQUEST']._serialized_start=366
  _globals['_GETKEYSREQUEST']._serialized_end=424
  _globals['_GETKEYSRESPONSE']._serialized_start=426
  _globals['_GETKEYSRESPONSE']._serialized_end=487
  _globals['_GETKEYREQUEST']._serialized_start=489
  _globals['_GETKEYREQUEST']._serialized_end=520
  _globals['_GETKEYRESPONSE']._serialized_start=522
  _globals['_GETKEYRESPONSE']._serialized_end=580
  _globals['_DEACTIVATEFIELDENCRYPTIONKEYREQUEST']._serialized_start=582
  _globals['_DEACTIVATEFIELDENCRYPTIONKEYREQUEST']._serialized_end=635
  _globals['_DEACTIVATEFIELDENCRYPTIONKEYRESPONSE']._serialized_start=637
  _globals['_DEACTIVATEFIELDENCRYPTIONKEYRESPONSE']._serialized_end=675
  _globals['_KMSSERVICE']._serialized_start=678
  _globals['_KMSSERVICE']._serialized_end=1048
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/types/v1/integration_log.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/types/v1/integration_log.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'admin/v1/types/v1/integration_log.proto\x12\x11\x61\x64min.v1.types.v1\"\xf1\x01\n\x0fIntegrationLogs\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\x12\x1d\n\ncreated_at\x18\x04 \x01(\x05R\tcreatedAt\x12\x17\n\x07\x64\x64_site\x18\x05 \x01(\tR\x06\x64\x64Site\x12\"\n\rdd_account_id\x18\x06 \x01(\tR\x0b\x64\x64\x41\x63\x63ountId\x12\x1d\n\nsplunk_url\x18\x07 \x01(\tR\tsplunkUrl\x12+\n\x12\x61ws_s3_bucket_name\x18\x08 \x01(\tR\x0f\x61wsS3BucketNameB\xe1\x01\n\x15\x63om.admin.v1.types.v1B\x13IntegrationLogProtoP\x01ZLgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1/types/v1;typesv1\xa2\x02\x03\x41VT\xaa\x02\x11\x41\x64min.V1.Types.V1\xca\x02\x11\x41\x64min\\V1\\Types\\V1\xe2\x02\x1d\x41\x64min\\V1\\Types\\V1\\GPBMetadata\xea\x02\x14\x41\x64min::V1::Types::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.types.v1.integration_log_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.admin.v1.types.v1B\023IntegrationLogProtoP\001ZLgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1/types/v1;typesv1\242\002\003AVT\252\002\021Admin.V1.Types.V1\312\002\021Admin\\V1\\Types\\V1\342\002\035Admin\\V1\\Types\\V1\\GPBMetadata\352\002\024Admin::V1::Types::V1'
  _globals['_INTEGRATIONLOGS']._serialized_start=63
  _globals['_INTEGRATIONLOGS']._serialized_end=304
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FlatDataplane(_message.Message):
    __slots__ = ("id", "name", "region", "customer_vpc_id", "original_customer_vpc_id", "cloud_account_id", "availability_zone", "vpc_peering_connection_id", "formal_r53_private_hosted_zone_id", "formal_vpc_flow_logs_group_arn", "formal_vpc_flow_log_group_name", "formal_vpc_flow_logs_iam_role_arn", "formal_vpc_flow_logs_iam_policy_arn", "formal_vpc_igw_id", "egress_only_igw", "formal_vpc_private_subnets_ids", "formal_vpc_public_subnets_ids", "formal_public_subnets", "formal_private_subnets", "formal_vpc_public_route_table_id", "customer_vpc_route_tables", "formal_vpc_natg_ids", "formal_vpc_natg_eips", "formal_vpc_public_route_tables", "formal_vpc_private_route_table_routes", "formal_vpc_id", "formal_vpc_cidr_block", "ecs_cluster_name", "ecs_cluster_arn", "status", "vpc_peering")
    class FormalVpcPrivateSubnetsIdsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    class FormalVpcPublicSubnetsIdsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    class FormalVpcNatgIdsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    class FormalVpcNatgEipsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    REGION_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_VPC_ID_FIELD_NUMBER: _ClassVar[int]
    ORIGINAL_CUSTOMER_VPC_ID_FIELD_NUMBER: _ClassVar[int]
    CLOUD_ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    AVAILABILITY_ZONE_FIELD_NUMBER: _ClassVar[int]
    VPC_PEERING_CONNECTION_ID_FIELD_NUMBER: _ClassVar[int]
    FORMAL_R53_PRIVATE_HOSTED_ZONE_ID_FIELD_NUMBER: _ClassVar[int]
    FORMAL_VPC_FLOW_LOGS_GROUP_ARN_FIELD_NUMBER: _ClassVar[int]
    FORMAL_VPC_FLOW_LOG_GROUP_NAME_FIELD_NUMBER: _ClassVar[int]
    FORMAL_VPC_FLOW_LOGS_IAM_ROLE_ARN_FIELD_NUMBER: _ClassVar[int]
    FORMAL_VPC_FLOW_LOGS_IAM_POLICY_ARN_FIELD_NUMBER: _ClassVar[int]
    FORMAL_VPC_IGW_ID_FIELD_NUMBER: _ClassVar[int]
    EGRESS_ONLY_IGW_FIELD_NUMBER: _ClassVar[int]
    FORMAL_VPC_PRIVATE_SUBNETS_IDS_FIELD_NUMBER: _ClassVar[int]
    FORMAL_VPC_PUBLIC_SUBNETS_IDS_FIELD_NUMBER: _ClassVar[int]
    FORMAL_PUBLIC_SUBNETS_FIELD_NUMBER: _ClassVar[int]
    FORMAL_PRIVATE_SUBNETS_FIELD_NUMBER: _ClassVar[int]
    FORMAL_VPC_PUBLIC_ROUTE_TABLE_ID_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_VPC_ROUTE_TABLES_FIELD_NUMBER: _ClassVar[int]
    FORMAL_VPC_NATG_IDS_FIELD_NUMBER: _ClassVar[int]
    FORMAL_VPC_NATG_EIPS_FIELD_NUMBER: _ClassVar[int]
    FORMAL_VPC_PUBLIC_ROUTE_TABLES_FIELD_NUMBER: _ClassVar[int]
    FORMAL_VPC_PRIVATE_ROUTE_TABLE_ROUTES_FIELD_NUMBER: _ClassVar[int]
    FORMAL_VPC_ID_FIELD_NUMBER: _ClassVar[int]
    FORMAL_VPC_CIDR_BLOCK_FIELD_NUMBER: _ClassVar[int]
    ECS_CLUSTER_NAME_FIELD_NUMBER: _ClassVar[int]
    ECS_CLUSTER_ARN_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    VPC_PEERING_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    region: str
    customer_vpc_id: str
    original_customer_vpc_id: str
    cloud_account_id: str
    availability_zone: int
    vpc_peering_connection_id: str
    formal_r53_private_hosted_zone_id: str
    formal_vpc_flow_logs_group_arn: str
    formal_vpc_flow_log_group_name: str
    formal_vpc_flow_logs_iam_role_arn: str
    formal_vpc_flow_logs_iam_policy_arn: str
    formal_vpc_igw_id: str
    egress_only_igw: str
    formal_vpc_private_subnets_ids: _containers.ScalarMap[str, str]
    formal_vpc_public_subnets_ids: _containers.ScalarMap[str, str]
    formal_public_subnets: _containers.RepeatedScalarFieldContainer[str]
    formal_private_subnets: _containers.RepeatedScalarFieldContainer[str]
    formal_vpc_public_route_table_id: str
    customer_vpc_route_tables: _containers.RepeatedScalarFieldContainer[str]
    formal_vpc_natg_ids: _containers.ScalarMap[str, str]
    formal_vpc_natg_eips: _containers.ScalarMap[str, str]
    formal_vpc_public_route_tables: str
    formal_vpc_private_route_table_routes: _containers.RepeatedScalarFieldContainer[str]
    formal_vpc_id: str
    formal_vpc_cidr_block: str
    ecs_cluster_name: str
    ecs_cluster_arn: str
    status: str
    vpc_peering: bool
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., region: _Optional[str] = ..., customer_vpc_id: _Optional[str] = ..., original_customer_vpc_id: _Optional[str] = ..., cloud_account_id: _Optional[str] = ..., availability_zone: _Optional[int] = ..., vpc_peering_connection_id: _Optional[str] = ..., formal_r53_private_hosted_zone_id: _Optional[str] = ..., formal_vpc_flow_logs_group_arn: _Optional[str] = ..., formal_vpc_flow_log_group_name: _Optional[str] = ..., formal_vpc_flow_logs_iam_role_arn: _Optional[str] = ..., formal_vpc_flow_logs_iam_policy_arn: _Optional[str] = ..., formal_vpc_igw_id: _Optional[str] = ..., egress_only_igw: _Optional[str] = ..., formal_vpc_private_subnets_ids: _Optional[_Mapping[str, str]] = ..., formal_vpc_public_subnets_ids: _Optional[_Mapping[str, str]] = ..., formal_public_subnets: _Optional[_Iterable[str]] = ..., formal_private_subnets: _Optional[_Iterable[str]] = ..., formal_vpc_public_route_table_id: _Optional[str] = ..., customer_vpc_route_tables: _Optional[_Iterable[str]] = ..., formal_vpc_natg_ids: _Optional[_Mapping[str, str]] = ..., formal_vpc_natg_eips: _Optional[_Mapping[str, str]] = ..., formal_vpc_public_route_tables: _Optional[str] = ..., formal_vpc_private_route_table_routes: _Optional[_Iterable[str]] = ..., formal_vpc_id: _Optional[str] = ..., formal_vpc_cidr_block: _Optional[str] = ..., ecs_cluster_name: _Optional[str] = ..., ecs_cluster_arn: _Optional[str] = ..., status: _Optional[str] = ..., vpc_peering: bool = ...) -> None: ...

class DataplaneTransitGatewayRoutes(_message.Message):
    __slots__ = ("id", "dataplane_id", "destination_cidr_block", "transit_gateway_id", "vpc_peering_connection_id", "deployed")
    ID_FIELD_NUMBER: _ClassVar[int]
    DATAPLANE_ID_FIELD_NUMBER: _ClassVar[int]
    DESTINATION_CIDR_BLOCK_FIELD_NUMBER: _ClassVar[int]
    TRANSIT_GATEWAY_ID_FIELD_NUMBER: _ClassVar[int]
    VPC_PEERING_CONNECTION_ID_FIELD_NUMBER: _ClassVar[int]
    DEPLOYED_FIELD_NUMBER: _ClassVar[int]
    id: str
    dataplane_id: str
    destination_cidr_block: str
    transit_gateway_id: str
    vpc_peering_connection_id: str
    deployed: bool
    def __init__(self, id: _Optional[str] = ..., dataplane_id: _Optional[str] = ..., destination_cidr_block: _Optional[str] = ..., transit_gateway_id: _Optional[str] = ..., vpc_peering_connection_id: _Optional[str] = ..., deployed: bool = ...) -> None: ...

class CloudIntegration(_message.Message):
    __slots__ = ("id", "aws_formal_id", "cloud_account_name", "url", "cloud_provider", "aws_account_id", "aws_formal_iam_role", "aws_formal_handshake_id", "gcp_project_id", "template_body", "aws_formal_user_name", "aws_formal_pingback_arn", "aws_formal_stack_name", "aws_cloud_region", "aws_formal_r53_private_hosted_zone_id", "stacks", "created_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    AWS_FORMAL_ID_FIELD_NUMBER: _ClassVar[int]
    CLOUD_ACCOUNT_NAME_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    CLOUD_PROVIDER_FIELD_NUMBER: _ClassVar[int]
    AWS_ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    AWS_FORMAL_IAM_ROLE_FIELD_NUMBER: _ClassVar[int]
    AWS_FORMAL_HANDSHAKE_ID_FIELD_NUMBER: _ClassVar[int]
    GCP_PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    TEMPLATE_BODY_FIELD_NUMBER: _ClassVar[int]
    AWS_FORMAL_USER_NAME_FIELD_NUMBER: _ClassVar[int]
    AWS_FORMAL_PINGBACK_ARN_FIELD_NUMBER: _ClassVar[int]
    AWS_FORMAL_STACK_NAME_FIELD_NUMBER: _ClassVar[int]
    AWS_CLOUD_REGION_FIELD_NUMBER: _ClassVar[int]
    AWS_FORMAL_R53_PRIVATE_HOSTED_ZONE_ID_FIELD_NUMBER: _ClassVar[int]
    STACKS_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    aws_formal_id: str
    cloud_account_name: str
    url: str
    cloud_provider: str
    aws_account_id: str
    aws_formal_iam_role: str
    aws_formal_handshake_id: str
    gcp_project_id: str
    template_body: str
    aws_formal_user_name: str
    aws_formal_pingback_arn: str
    aws_formal_stack_name: str
    aws_cloud_region: str
    aws_formal_r53_private_hosted_zone_id: str
    stacks: _containers.RepeatedCompositeFieldContainer[FlatDataplane]
    created_at: str
    def __init__(self, id: _Optional[str] = ..., aws_formal_id: _Optional[str] = ..., cloud_account_name: _Optional[str] = ..., url: _Optional[str] = ..., cloud_provider: _Optional[str] = ..., aws_account_id: _Optional[str] = ..., aws_formal_iam_role: _Optional[str] = ..., aws_formal_handshake_id: _Optional[str] = ..., gcp_project_id: _Optional[str] = ..., template_body: _Optional[str] = ..., aws_formal_user_name: _Optional[str] = ..., aws_formal_pingback_arn: _Optional[str] = ..., aws_formal_stack_name: _Optional[str] = ..., aws_cloud_region: _Optional[str] = ..., aws_formal_r53_private_hosted_zone_id: _Optional[str] = ..., stacks: _Optional[_Iterable[_Union[FlatDataplane, _Mapping]]] = ..., created_at: _Optional[str] = ...) -> None: ...



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetMetricsRequest(_message.Message):
    __slots__ = ("datastore_id", "interval", "user_id")
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    INTERVAL_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    datastore_id: _containers.RepeatedScalarFieldContainer[str]
    interval: str
    user_id: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, datastore_id: _Optional[_Iterable[str]] = ..., interval: _Optional[str] = ..., user_id: _Optional[_Iterable[str]] = ...) -> None: ...

class Metric(_message.Message):
    __slots__ = ("name", "path", "column_name", "column_path", "table_name", "table_path", "schema_name", "schema_path", "db_name", "user_id", "db_user", "end_user_id", "end_user_db_username", "app_type", "datastore_id", "datastore_name", "ts", "counter", "returned_rows", "ip_address", "data_label", "data_labels", "datastore_technology", "bucket")
    NAME_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    COLUMN_NAME_FIELD_NUMBER: _ClassVar[int]
    COLUMN_PATH_FIELD_NUMBER: _ClassVar[int]
    TABLE_NAME_FIELD_NUMBER: _ClassVar[int]
    TABLE_PATH_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_NAME_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_PATH_FIELD_NUMBER: _ClassVar[int]
    DB_NAME_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    DB_USER_FIELD_NUMBER: _ClassVar[int]
    END_USER_ID_FIELD_NUMBER: _ClassVar[int]
    END_USER_DB_USERNAME_FIELD_NUMBER: _ClassVar[int]
    APP_TYPE_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_NAME_FIELD_NUMBER: _ClassVar[int]
    TS_FIELD_NUMBER: _ClassVar[int]
    COUNTER_FIELD_NUMBER: _ClassVar[int]
    RETURNED_ROWS_FIELD_NUMBER: _ClassVar[int]
    IP_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    DATA_LABEL_FIELD_NUMBER: _ClassVar[int]
    DATA_LABELS_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_TECHNOLOGY_FIELD_NUMBER: _ClassVar[int]
    BUCKET_FIELD_NUMBER: _ClassVar[int]
    name: str
    path: str
    column_name: str
    column_path: str
    table_name: str
    table_path: str
    schema_name: str
    schema_path: str
    db_name: str
    user_id: str
    db_user: str
    end_user_id: str
    end_user_db_username: str
    app_type: str
    datastore_id: str
    datastore_name: str
    ts: _timestamp_pb2.Timestamp
    counter: int
    returned_rows: int
    ip_address: str
    data_label: str
    data_labels: _containers.RepeatedScalarFieldContainer[str]
    datastore_technology: str
    bucket: _timestamp_pb2.Timestamp
    def __init__(self, name: _Optional[str] = ..., path: _Optional[str] = ..., column_name: _Optional[str] = ..., column_path: _Optional[str] = ..., table_name: _Optional[str] = ..., table_path: _Optional[str] = ..., schema_name: _Optional[str] = ..., schema_path: _Optional[str] = ..., db_name: _Optional[str] = ..., user_id: _Optional[str] = ..., db_user: _Optional[str] = ..., end_user_id: _Optional[str] = ..., end_user_db_username: _Optional[str] = ..., app_type: _Optional[str] = ..., datastore_id: _Optional[str] = ..., datastore_name: _Optional[str] = ..., ts: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., counter: _Optional[int] = ..., returned_rows: _Optional[int] = ..., ip_address: _Optional[str] = ..., data_label: _Optional[str] = ..., data_labels: _Optional[_Iterable[str]] = ..., datastore_technology: _Optional[str] = ..., bucket: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class Node(_message.Message):
    __slots__ = ("id", "type", "shape", "color", "label")
    ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    SHAPE_FIELD_NUMBER: _ClassVar[int]
    COLOR_FIELD_NUMBER: _ClassVar[int]
    LABEL_FIELD_NUMBER: _ClassVar[int]
    id: str
    type: str
    shape: str
    color: str
    label: str
    def __init__(self, id: _Optional[str] = ..., type: _Optional[str] = ..., shape: _Optional[str] = ..., color: _Optional[str] = ..., label: _Optional[str] = ...) -> None: ...

class Link(_message.Message):
    __slots__ = ("source", "target")
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    TARGET_FIELD_NUMBER: _ClassVar[int]
    source: str
    target: str
    def __init__(self, source: _Optional[str] = ..., target: _Optional[str] = ...) -> None: ...

class GetMetricsResponse(_message.Message):
    __slots__ = ("metrics", "nodes", "links")
    METRICS_FIELD_NUMBER: _ClassVar[int]
    NODES_FIELD_NUMBER: _ClassVar[int]
    LINKS_FIELD_NUMBER: _ClassVar[int]
    metrics: _containers.RepeatedCompositeFieldContainer[Metric]
    nodes: _containers.RepeatedCompositeFieldContainer[Node]
    links: _containers.RepeatedCompositeFieldContainer[Link]
    def __init__(self, metrics: _Optional[_Iterable[_Union[Metric, _Mapping]]] = ..., nodes: _Optional[_Iterable[_Union[Node, _Mapping]]] = ..., links: _Optional[_Iterable[_Union[Link, _Mapping]]] = ...) -> None: ...

class RowLevelMetric(_message.Message):
    __slots__ = ("datastore_id", "datastore_name", "end_user_id", "end_user_db_username", "user_id", "db_user", "db_name", "schema_name", "table_name", "path", "hashed_row_level_value", "clear_text_row_level_value", "timestamp", "queries_count", "rows_count", "time_bucket")
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_NAME_FIELD_NUMBER: _ClassVar[int]
    END_USER_ID_FIELD_NUMBER: _ClassVar[int]
    END_USER_DB_USERNAME_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    DB_USER_FIELD_NUMBER: _ClassVar[int]
    DB_NAME_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_NAME_FIELD_NUMBER: _ClassVar[int]
    TABLE_NAME_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    HASHED_ROW_LEVEL_VALUE_FIELD_NUMBER: _ClassVar[int]
    CLEAR_TEXT_ROW_LEVEL_VALUE_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    QUERIES_COUNT_FIELD_NUMBER: _ClassVar[int]
    ROWS_COUNT_FIELD_NUMBER: _ClassVar[int]
    TIME_BUCKET_FIELD_NUMBER: _ClassVar[int]
    datastore_id: str
    datastore_name: str
    end_user_id: str
    end_user_db_username: str
    user_id: str
    db_user: str
    db_name: str
    schema_name: str
    table_name: str
    path: str
    hashed_row_level_value: str
    clear_text_row_level_value: str
    timestamp: _timestamp_pb2.Timestamp
    queries_count: int
    rows_count: int
    time_bucket: _timestamp_pb2.Timestamp
    def __init__(self, datastore_id: _Optional[str] = ..., datastore_name: _Optional[str] = ..., end_user_id: _Optional[str] = ..., end_user_db_username: _Optional[str] = ..., user_id: _Optional[str] = ..., db_user: _Optional[str] = ..., db_name: _Optional[str] = ..., schema_name: _Optional[str] = ..., table_name: _Optional[str] = ..., path: _Optional[str] = ..., hashed_row_level_value: _Optional[str] = ..., clear_text_row_level_value: _Optional[str] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., queries_count: _Optional[int] = ..., rows_count: _Optional[int] = ..., time_bucket: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class RowLevelMetricConfiguration(_message.Message):
    __slots__ = ("datastore_id", "id", "metric_id", "path", "allow_clear_text_value", "created_at")
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    METRIC_ID_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    ALLOW_CLEAR_TEXT_VALUE_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    datastore_id: str
    id: str
    metric_id: str
    path: str
    allow_clear_text_value: bool
    created_at: _timestamp_pb2.Timestamp
    def __init__(self, datastore_id: _Optional[str] = ..., id: _Optional[str] = ..., metric_id: _Optional[str] = ..., path: _Optional[str] = ..., allow_clear_text_value: bool = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class GetCustomMetricsDetailsRequest(_message.Message):
    __slots__ = ("id", "interval", "user_id")
    ID_FIELD_NUMBER: _ClassVar[int]
    INTERVAL_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    interval: str
    user_id: str
    def __init__(self, id: _Optional[str] = ..., interval: _Optional[str] = ..., user_id: _Optional[str] = ...) -> None: ...

class GetCustomMetricsDetailsResponse(_message.Message):
    __slots__ = ("series",)
    class SeriesEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: MetricsGroup
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[MetricsGroup, _Mapping]] = ...) -> None: ...
    SERIES_FIELD_NUMBER: _ClassVar[int]
    series: _containers.MessageMap[str, MetricsGroup]
    def __init__(self, series: _Optional[_Mapping[str, MetricsGroup]] = ...) -> None: ...

class MetricsGroup(_message.Message):
    __slots__ = ("metrics", "clear_text")
    METRICS_FIELD_NUMBER: _ClassVar[int]
    CLEAR_TEXT_FIELD_NUMBER: _ClassVar[int]
    metrics: _containers.RepeatedCompositeFieldContainer[RowLevelMetric]
    clear_text: str
    def __init__(self, metrics: _Optional[_Iterable[_Union[RowLevelMetric, _Mapping]]] = ..., clear_text: _Optional[str] = ...) -> None: ...

class GetCustomMetricsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetCustomMetricsResponse(_message.Message):
    __slots__ = ("row_level_metric_configurations",)
    ROW_LEVEL_METRIC_CONFIGURATIONS_FIELD_NUMBER: _ClassVar[int]
    row_level_metric_configurations: _containers.RepeatedCompositeFieldContainer[RowLevelMetricConfiguration]
    def __init__(self, row_level_metric_configurations: _Optional[_Iterable[_Union[RowLevelMetricConfiguration, _Mapping]]] = ...) -> None: ...

class CreateCustomMetricRequest(_message.Message):
    __slots__ = ("datastore_id", "path", "allow_clear_text_value")
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    ALLOW_CLEAR_TEXT_VALUE_FIELD_NUMBER: _ClassVar[int]
    datastore_id: str
    path: str
    allow_clear_text_value: bool
    def __init__(self, datastore_id: _Optional[str] = ..., path: _Optional[str] = ..., allow_clear_text_value: bool = ...) -> None: ...

class CreateCustomMetricResponse(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteCustomMetricRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteCustomMetricResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from .types.v1 import integration_log_pb2 as _integration_log_pb2
from .types.v1 import log_link_pb2 as _log_link_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateIntegrationLogsRequest(_message.Message):
    __slots__ = ("name", "type", "dd_site", "dd_api_key", "dd_account_id", "splunk_url", "splunk_api_key", "aws_access_key_id", "aws_secret_access_key", "aws_region", "aws_s3_bucket")
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    DD_SITE_FIELD_NUMBER: _ClassVar[int]
    DD_API_KEY_FIELD_NUMBER: _ClassVar[int]
    DD_ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    SPLUNK_URL_FIELD_NUMBER: _ClassVar[int]
    SPLUNK_API_KEY_FIELD_NUMBER: _ClassVar[int]
    AWS_ACCESS_KEY_ID_FIELD_NUMBER: _ClassVar[int]
    AWS_SECRET_ACCESS_KEY_FIELD_NUMBER: _ClassVar[int]
    AWS_REGION_FIELD_NUMBER: _ClassVar[int]
    AWS_S3_BUCKET_FIELD_NUMBER: _ClassVar[int]
    name: str
    type: str
    dd_site: str
    dd_api_key: str
    dd_account_id: str
    splunk_url: str
    splunk_api_key: str
    aws_access_key_id: str
    aws_secret_access_key: str
    aws_region: str
    aws_s3_bucket: str
    def __init__(self, name: _Optional[str] = ..., type: _Optional[str] = ..., dd_site: _Optional[str] = ..., dd_api_key: _Optional[str] = ..., dd_account_id: _Optional[str] = ..., splunk_url: _Optional[str] = ..., splunk_api_key: _Optional[str] = ..., aws_access_key_id: _Optional[str] = ..., aws_secret_access_key: _Optional[str] = ..., aws_region: _Optional[str] = ..., aws_s3_bucket: _Optional[str] = ...) -> None: ...

class CreateIntegrationLogsResponse(_message.Message):
    __slots__ = ("integration",)
    INTEGRATION_FIELD_NUMBER: _ClassVar[int]
    integration: _integration_log_pb2.IntegrationLogs
    def __init__(self, integration: _Optional[_Union[_integration_log_pb2.IntegrationLogs, _Mapping]] = ...) -> None: ...

class GetIntegrationLogsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetIntegrationLogsResponse(_message.Message):
    __slots__ = ("integrations",)
    INTEGRATIONS_FIELD_NUMBER: _ClassVar[int]
    integrations: _containers.RepeatedCompositeFieldContainer[_integration_log_pb2.IntegrationLogs]
    def __init__(self, integrations: _Optional[_Iterable[_Union[_integration_log_pb2.IntegrationLogs, _Mapping]]] = ...) -> None: ...

class GetIntegrationLogByIdRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetIntegrationLogByIdResponse(_message.Message):
    __slots__ = ("integration",)
    INTEGRATION_FIELD_NUMBER: _ClassVar[int]
    integration: _integration_log_pb2.IntegrationLogs
    def __init__(self, integration: _Optional[_Union[_integration_log_pb2.IntegrationLogs, _Mapping]] = ...) -> None: ...

class DeleteIntegrationLogsRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteIntegrationLogsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class CreateLogsLinkItemRequest(_message.Message):
    __slots__ = ("integration_id", "datastore_id")
    INTEGRATION_ID_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    integration_id: str
    datastore_id: str
    def __init__(self, integration_id: _Optional[str] = ..., datastore_id: _Optional[str] = ...) -> None: ...

class CreateLogsLinkItemResponse(_message.Message):
    __slots__ = ("log_item_link",)
    LOG_ITEM_LINK_FIELD_NUMBER: _ClassVar[int]
    log_item_link: _log_link_pb2.LogLinkItem
    def __init__(self, log_item_link: _Optional[_Union[_log_link_pb2.LogLinkItem, _Mapping]] = ...) -> None: ...

class GetLogsLinkItemByIdRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetLogsLinkItemByIdResponse(_message.Message):
    __slots__ = ("log_item_links",)
    LOG_ITEM_LINKS_FIELD_NUMBER: _ClassVar[int]
    log_item_links: _log_link_pb2.LogLinkItem
    def __init__(self, log_item_links: _Optional[_Union[_log_link_pb2.LogLinkItem, _Mapping]] = ...) -> None: ...

class DeleteLogsLinkItemRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteLogsLinkItemResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ConnectionType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    CONNECTION_TYPE_UNSPECIFIED: _ClassVar[ConnectionType]
    CONNECTION_TYPE_ADFS_SAML: _ClassVar[ConnectionType]
    CONNECTION_TYPE_ADP_OIDC: _ClassVar[ConnectionType]
    CONNECTION_TYPE_AUTH0_SAML: _ClassVar[ConnectionType]
    CONNECTION_TYPE_AZURE_SAML: _ClassVar[ConnectionType]
    CONNECTION_TYPE_CAS_SAML: _ClassVar[ConnectionType]
    CONNECTION_TYPE_CLOUDFLARE_SAML: _ClassVar[ConnectionType]
    CONNECTION_TYPE_CLASS_LINK_SAML: _ClassVar[ConnectionType]
    CONNECTION_TYPE_CYBERARK_SAML: _ClassVar[ConnectionType]
    CONNECTION_TYPE_DUO_SAML: _ClassVar[ConnectionType]
    CONNECTION_TYPE_GENERIC_OIDC: _ClassVar[ConnectionType]
    CONNECTION_TYPE_GENERIC_SAML: _ClassVar[ConnectionType]
    CONNECTION_TYPE_GOOGLE_OAUTH: _ClassVar[ConnectionType]
    CONNECTION_TYPE_GOOGLE_SAML: _ClassVar[ConnectionType]
    CONNECTION_TYPE_JUMP_CLOUD_SAML: _ClassVar[ConnectionType]
    CONNECTION_TYPE_MAGIC_LINK: _ClassVar[ConnectionType]
    CONNECTION_TYPE_MICROSOFT_OAUTH: _ClassVar[ConnectionType]
    CONNECTION_TYPE_MINIORANGE_SAML: _ClassVar[ConnectionType]
    CONNECTION_TYPE_NETIQ_SAML: _ClassVar[ConnectionType]
    CONNECTION_TYPE_OKTA_SAML: _ClassVar[ConnectionType]
    CONNECTION_TYPE_ONELOGIN_SAML: _ClassVar[ConnectionType]
    CONNECTION_TYPE_ORACLE_SAML: _ClassVar[ConnectionType]
    CONNECTION_TYPE_PING_FEDERATE_SAML: _ClassVar[ConnectionType]
    CONNECTION_TYPE_PING_ONE_SAML: _ClassVar[ConnectionType]
    CONNECTION_TYPE_RIPPLING_SAML: _ClassVar[ConnectionType]
    CONNECTION_TYPE_SALESFORCE_SAML: _ClassVar[ConnectionType]
    CONNECTION_TYPE_SHIBBOLETH_SAML: _ClassVar[ConnectionType]
    CONNECTION_TYPE_SIMPLE_SAML_PHP_SAML: _ClassVar[ConnectionType]
    CONNECTION_TYPE_VMWARE_SAML: _ClassVar[ConnectionType]

class ConnectionStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    CONNECTION_STATUS_UNSPECIFIED: _ClassVar[ConnectionStatus]
    CONNECTION_STATUS_LINKED: _ClassVar[ConnectionStatus]
    CONNECTION_STATUS_UNLINKED: _ClassVar[ConnectionStatus]

class ConnectionState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    CONNECTION_STATE_UNSPECIFIED: _ClassVar[ConnectionState]
    CONNECTION_STATE_DRAFT: _ClassVar[ConnectionState]
    CONNECTION_STATE_ACTIVE: _ClassVar[ConnectionState]
    CONNECTION_STATE_INACTIVE: _ClassVar[ConnectionState]
CONNECTION_TYPE_UNSPECIFIED: ConnectionType
CONNECTION_TYPE_ADFS_SAML: ConnectionType
CONNECTION_TYPE_ADP_OIDC: ConnectionType
CONNECTION_TYPE_AUTH0_SAML: ConnectionType
CONNECTION_TYPE_AZURE_SAML: ConnectionType
CONNECTION_TYPE_CAS_SAML: ConnectionType
CONNECTION_TYPE_CLOUDFLARE_SAML: ConnectionType
CONNECTION_TYPE_CLASS_LINK_SAML: ConnectionType
CONNECTION_TYPE_CYBERARK_SAML: ConnectionType
CONNECTION_TYPE_DUO_SAML: ConnectionType
CONNECTION_TYPE_GENERIC_OIDC: ConnectionType
CONNECTION_TYPE_GENERIC_SAML: ConnectionType
CONNECTION_TYPE_GOOGLE_OAUTH: ConnectionType
CONNECTION_TYPE_GOOGLE_SAML: ConnectionType
CONNECTION_TYPE_JUMP_CLOUD_SAML: ConnectionType
CONNECTION_TYPE_MAGIC_LINK: ConnectionType
CONNECTION_TYPE_MICROSOFT_OAUTH: ConnectionType
CONNECTION_TYPE_MINIORANGE_SAML: ConnectionType
CONNECTION_TYPE_NETIQ_SAML: ConnectionType
CONNECTION_TYPE_OKTA_SAML: ConnectionType
CONNECTION_TYPE_ONELOGIN_SAML: ConnectionType
CONNECTION_TYPE_ORACLE_SAML: ConnectionType
CONNECTION_TYPE_PING_FEDERATE_SAML: ConnectionType
CONNECTION_TYPE_PING_ONE_SAML: ConnectionType
CONNECTION_TYPE_RIPPLING_SAML: ConnectionType
CONNECTION_TYPE_SALESFORCE_SAML: ConnectionType
CONNECTION_TYPE_SHIBBOLETH_SAML: ConnectionType
CONNECTION_TYPE_SIMPLE_SAML_PHP_SAML: ConnectionType
CONNECTION_TYPE_VMWARE_SAML: ConnectionType
CONNECTION_STATUS_UNSPECIFIED: ConnectionStatus
CONNECTION_STATUS_LINKED: ConnectionStatus
CONNECTION_STATUS_UNLINKED: ConnectionStatus
CONNECTION_STATE_UNSPECIFIED: ConnectionState
CONNECTION_STATE_DRAFT: ConnectionState
CONNECTION_STATE_ACTIVE: ConnectionState
CONNECTION_STATE_INACTIVE: ConnectionState

class Connection(_message.Message):
    __slots__ = ("id", "status", "state", "name", "connection_type", "organization_id", "domains", "created_at", "updated_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CONNECTION_TYPE_FIELD_NUMBER: _ClassVar[int]
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    DOMAINS_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    status: ConnectionStatus
    state: ConnectionState
    name: str
    connection_type: ConnectionType
    organization_id: str
    domains: _containers.RepeatedCompositeFieldContainer[ConnectionDomain]
    created_at: str
    updated_at: str
    def __init__(self, id: _Optional[str] = ..., status: _Optional[_Union[ConnectionStatus, str]] = ..., state: _Optional[_Union[ConnectionState, str]] = ..., name: _Optional[str] = ..., connection_type: _Optional[_Union[ConnectionType, str]] = ..., organization_id: _Optional[str] = ..., domains: _Optional[_Iterable[_Union[ConnectionDomain, _Mapping]]] = ..., created_at: _Optional[str] = ..., updated_at: _Optional[str] = ...) -> None: ...

class ConnectionDomain(_message.Message):
    __slots__ = ("id", "domain")
    ID_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    id: str
    domain: str
    def __init__(self, id: _Optional[str] = ..., domain: _Optional[str] = ...) -> None: ...



import grpc


from .gen.admin.v1.admin_pb2 import (
	GetApiKeysRequest,
	ApiKey,
	GetApiKeysResponse,
	CreateApiKeyRequest,
	CreateApiKeyResponse,
	DeleteApiKeyRequest,
	DeleteApiKeyResponse,
)

from .gen.admin.v1.admin_pb2_grpc import DevServiceStub
class DevService:
	def __init__(self, base_url, token):
		self.base_url = base_url
		self.channel = grpc.secure_channel(self.base_url, grpc.ssl_channel_credentials())
		self.stub = DevServiceStub(self.channel)
		self.headers = [('x-api-key', token)]

	def GetApiKeys(self, request: GetApiKeysRequest) -> GetApiKeysResponse:
		return self.stub.GetApiKeys(request, metadata=self.headers)

	def CreateApiKey(self, request: CreateApiKeyRequest) -> CreateApiKeyResponse:
		return self.stub.CreateApiKey(request, metadata=self.headers)

	def DeleteApiKey(self, request: DeleteApiKeyRequest) -> DeleteApiKeyResponse:
		return self.stub.DeleteApiKey(request, metadata=self.headers)




from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DeploymentType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    DEPLOYMENT_TYPE_UNSPECIFIED: _ClassVar[DeploymentType]
    DEPLOYMENT_TYPE_ONPREM: _ClassVar[DeploymentType]
    DEPLOYMENT_TYPE_MANAGED: _ClassVar[DeploymentType]

class NetworkType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    NETWORK_TYPE_UNSPECIFIED: _ClassVar[NetworkType]
    NETWORK_TYPE_INTERNET_FACING: _ClassVar[NetworkType]
    NETWORK_TYPE_INTERNAL: _ClassVar[NetworkType]
    NETWORK_TYPE_INTERNET_AND_INTERNAL: _ClassVar[NetworkType]

class CloudProvider(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    CLOUD_PROVIDER_UNSPECIFIED: _ClassVar[CloudProvider]
    CLOUD_PROVIDER_AWS: _ClassVar[CloudProvider]
    CLOUD_PROVIDER_AZURE: _ClassVar[CloudProvider]
    CLOUD_PROVIDER_GCP: _ClassVar[CloudProvider]
DEPLOYMENT_TYPE_UNSPECIFIED: DeploymentType
DEPLOYMENT_TYPE_ONPREM: DeploymentType
DEPLOYMENT_TYPE_MANAGED: DeploymentType
NETWORK_TYPE_UNSPECIFIED: NetworkType
NETWORK_TYPE_INTERNET_FACING: NetworkType
NETWORK_TYPE_INTERNAL: NetworkType
NETWORK_TYPE_INTERNET_AND_INTERNAL: NetworkType
CLOUD_PROVIDER_UNSPECIFIED: CloudProvider
CLOUD_PROVIDER_AWS: CloudProvider
CLOUD_PROVIDER_AZURE: CloudProvider
CLOUD_PROVIDER_GCP: CloudProvider

class Sidecar(_message.Message):
    __slots__ = ("id", "name", "cloud_account_id", "cloud_provider", "cloud_region", "technology", "deployment_type", "network_type", "dataplane_id", "datastore_id", "deployed", "version", "formal_hostname", "server_connection_status", "proxy_status", "fail_open", "global_kms_decrypt", "ssh_rsa_key", "server_error_message", "created_at", "termination_protection")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CLOUD_ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    CLOUD_PROVIDER_FIELD_NUMBER: _ClassVar[int]
    CLOUD_REGION_FIELD_NUMBER: _ClassVar[int]
    TECHNOLOGY_FIELD_NUMBER: _ClassVar[int]
    DEPLOYMENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    NETWORK_TYPE_FIELD_NUMBER: _ClassVar[int]
    DATAPLANE_ID_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    DEPLOYED_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    FORMAL_HOSTNAME_FIELD_NUMBER: _ClassVar[int]
    SERVER_CONNECTION_STATUS_FIELD_NUMBER: _ClassVar[int]
    PROXY_STATUS_FIELD_NUMBER: _ClassVar[int]
    FAIL_OPEN_FIELD_NUMBER: _ClassVar[int]
    GLOBAL_KMS_DECRYPT_FIELD_NUMBER: _ClassVar[int]
    SSH_RSA_KEY_FIELD_NUMBER: _ClassVar[int]
    SERVER_ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    TERMINATION_PROTECTION_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    cloud_account_id: str
    cloud_provider: CloudProvider
    cloud_region: str
    technology: str
    deployment_type: str
    network_type: str
    dataplane_id: str
    datastore_id: str
    deployed: bool
    version: str
    formal_hostname: str
    server_connection_status: str
    proxy_status: str
    fail_open: bool
    global_kms_decrypt: bool
    ssh_rsa_key: bytes
    server_error_message: str
    created_at: _timestamp_pb2.Timestamp
    termination_protection: bool
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., cloud_account_id: _Optional[str] = ..., cloud_provider: _Optional[_Union[CloudProvider, str]] = ..., cloud_region: _Optional[str] = ..., technology: _Optional[str] = ..., deployment_type: _Optional[str] = ..., network_type: _Optional[str] = ..., dataplane_id: _Optional[str] = ..., datastore_id: _Optional[str] = ..., deployed: bool = ..., version: _Optional[str] = ..., formal_hostname: _Optional[str] = ..., server_connection_status: _Optional[str] = ..., proxy_status: _Optional[str] = ..., fail_open: bool = ..., global_kms_decrypt: bool = ..., ssh_rsa_key: _Optional[bytes] = ..., server_error_message: _Optional[str] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., termination_protection: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/metrics.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/metrics.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x61\x64min/v1/metrics.proto\x12\x08\x61\x64min.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"k\n\x11GetMetricsRequest\x12!\n\x0c\x64\x61tastore_id\x18\x01 \x03(\tR\x0b\x64\x61tastoreId\x12\x1a\n\x08interval\x18\x02 \x01(\tR\x08interval\x12\x17\n\x07user_id\x18\x03 \x03(\tR\x06userId\"\xa4\x06\n\x06Metric\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04path\x18\x02 \x01(\tR\x04path\x12\x1f\n\x0b\x63olumn_name\x18\x03 \x01(\tR\ncolumnName\x12\x1f\n\x0b\x63olumn_path\x18\x04 \x01(\tR\ncolumnPath\x12\x1d\n\ntable_name\x18\x05 \x01(\tR\ttableName\x12\x1d\n\ntable_path\x18\x06 \x01(\tR\ttablePath\x12\x1f\n\x0bschema_name\x18\x07 \x01(\tR\nschemaName\x12\x1f\n\x0bschema_path\x18\x08 \x01(\tR\nschemaPath\x12\x17\n\x07\x64\x62_name\x18\t \x01(\tR\x06\x64\x62Name\x12\x17\n\x07user_id\x18\n \x01(\tR\x06userId\x12\x17\n\x07\x64\x62_user\x18\x0b \x01(\tR\x06\x64\x62User\x12\x1e\n\x0b\x65nd_user_id\x18\x0c \x01(\tR\tendUserId\x12/\n\x14\x65nd_user_db_username\x18\r \x01(\tR\x11\x65ndUserDbUsername\x12\x19\n\x08\x61pp_type\x18\x0e \x01(\tR\x07\x61ppType\x12!\n\x0c\x64\x61tastore_id\x18\x0f \x01(\tR\x0b\x64\x61tastoreId\x12%\n\x0e\x64\x61tastore_name\x18\x10 \x01(\tR\rdatastoreName\x12*\n\x02ts\x18\x11 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x02ts\x12\x18\n\x07\x63ounter\x18\x12 \x01(\x04R\x07\x63ounter\x12#\n\rreturned_rows\x18\x13 \x01(\x03R\x0creturnedRows\x12\x1d\n\nip_address\x18\x14 \x01(\tR\tipAddress\x12\x1d\n\ndata_label\x18\x15 \x01(\tR\tdataLabel\x12\x1f\n\x0b\x64\x61ta_labels\x18\x16 \x03(\tR\ndataLabels\x12\x31\n\x14\x64\x61tastore_technology\x18\x17 \x01(\tR\x13\x64\x61tastoreTechnology\x12\x32\n\x06\x62ucket\x18\x18 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x06\x62ucket\"l\n\x04Node\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x14\n\x05shape\x18\x03 \x01(\tR\x05shape\x12\x14\n\x05\x63olor\x18\x04 \x01(\tR\x05\x63olor\x12\x14\n\x05label\x18\x05 \x01(\tR\x05label\"6\n\x04Link\x12\x16\n\x06source\x18\x01 \x01(\tR\x06source\x12\x16\n\x06target\x18\x02 \x01(\tR\x06target\"\x8c\x01\n\x12GetMetricsResponse\x12*\n\x07metrics\x18\x01 \x03(\x0b\x32\x10.admin.v1.MetricR\x07metrics\x12$\n\x05nodes\x18\x02 \x03(\x0b\x32\x0e.admin.v1.NodeR\x05nodes\x12$\n\x05links\x18\x03 \x03(\x0b\x32\x0e.admin.v1.LinkR\x05links\"\xf6\x04\n\x0eRowLevelMetric\x12!\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tR\x0b\x64\x61tastoreId\x12%\n\x0e\x64\x61tastore_name\x18\x02 \x01(\tR\rdatastoreName\x12\x1e\n\x0b\x65nd_user_id\x18\x03 \x01(\tR\tendUserId\x12/\n\x14\x65nd_user_db_username\x18\x04 \x01(\tR\x11\x65ndUserDbUsername\x12\x17\n\x07user_id\x18\x05 \x01(\tR\x06userId\x12\x17\n\x07\x64\x62_user\x18\x06 \x01(\tR\x06\x64\x62User\x12\x17\n\x07\x64\x62_name\x18\x07 \x01(\tR\x06\x64\x62Name\x12\x1f\n\x0bschema_name\x18\x08 \x01(\tR\nschemaName\x12\x1d\n\ntable_name\x18\t \x01(\tR\ttableName\x12\x12\n\x04path\x18\n \x01(\tR\x04path\x12\x33\n\x16hashed_row_level_value\x18\x0b \x01(\tR\x13hashedRowLevelValue\x12:\n\x1a\x63lear_text_row_level_value\x18\x0c \x01(\tR\x16\x63learTextRowLevelValue\x12\x38\n\ttimestamp\x18\r \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12#\n\rqueries_count\x18\x0e \x01(\x03R\x0cqueriesCount\x12\x1d\n\nrows_count\x18\x0f \x01(\x03R\trowsCount\x12;\n\x0btime_bucket\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ntimeBucket\"\xf1\x01\n\x1bRowLevelMetricConfiguration\x12!\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tR\x0b\x64\x61tastoreId\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\x12\x1b\n\tmetric_id\x18\x03 \x01(\tR\x08metricId\x12\x12\n\x04path\x18\x04 \x01(\tR\x04path\x12\x33\n\x16\x61llow_clear_text_value\x18\x05 \x01(\x08R\x13\x61llowClearTextValue\x12\x39\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\"e\n\x1eGetCustomMetricsDetailsRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1a\n\x08interval\x18\x02 \x01(\tR\x08interval\x12\x17\n\x07user_id\x18\x03 \x01(\tR\x06userId\"\xc3\x01\n\x1fGetCustomMetricsDetailsResponse\x12M\n\x06series\x18\x01 \x03(\x0b\x32\x35.admin.v1.GetCustomMetricsDetailsResponse.SeriesEntryR\x06series\x1aQ\n\x0bSeriesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.admin.v1.MetricsGroupR\x05value:\x02\x38\x01\"a\n\x0cMetricsGroup\x12\x32\n\x07metrics\x18\x01 \x03(\x0b\x32\x18.admin.v1.RowLevelMetricR\x07metrics\x12\x1d\n\nclear_text\x18\x02 \x01(\tR\tclearText\"\x19\n\x17GetCustomMetricsRequest\"\x88\x01\n\x18GetCustomMetricsResponse\x12l\n\x1frow_level_metric_configurations\x18\x01 \x03(\x0b\x32%.admin.v1.RowLevelMetricConfigurationR\x1crowLevelMetricConfigurations\"\x87\x01\n\x19\x43reateCustomMetricRequest\x12!\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tR\x0b\x64\x61tastoreId\x12\x12\n\x04path\x18\x02 \x01(\tR\x04path\x12\x33\n\x16\x61llow_clear_text_value\x18\x03 \x01(\x08R\x13\x61llowClearTextValue\",\n\x1a\x43reateCustomMetricResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"+\n\x19\x44\x65leteCustomMetricRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x1c\n\x1a\x44\x65leteCustomMetricResponse2\xf0\x03\n\x0eMetricsService\x12I\n\nGetMetrics\x12\x1b.admin.v1.GetMetricsRequest\x1a\x1c.admin.v1.GetMetricsResponse\"\x00\x12\x61\n\x12\x43reateCustomMetric\x12#.admin.v1.CreateCustomMetricRequest\x1a$.admin.v1.CreateCustomMetricResponse\"\x00\x12[\n\x10GetCustomMetrics\x12!.admin.v1.GetCustomMetricsRequest\x1a\".admin.v1.GetCustomMetricsResponse\"\x00\x12p\n\x17GetCustomMetricsDetails\x12(.admin.v1.GetCustomMetricsDetailsRequest\x1a).admin.v1.GetCustomMetricsDetailsResponse\"\x00\x12\x61\n\x12\x44\x65leteCustomMetric\x12#.admin.v1.DeleteCustomMetricRequest\x1a$.admin.v1.DeleteCustomMetricResponse\"\x00\x42\xa2\x01\n\x0c\x63om.admin.v1B\x0cMetricsProtoP\x01ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.metrics_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\014MetricsProtoP\001ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_GETCUSTOMMETRICSDETAILSRESPONSE_SERIESENTRY']._loaded_options = None
  _globals['_GETCUSTOMMETRICSDETAILSRESPONSE_SERIESENTRY']._serialized_options = b'8\001'
  _globals['_GETMETRICSREQUEST']._serialized_start=69
  _globals['_GETMETRICSREQUEST']._serialized_end=176
  _globals['_METRIC']._serialized_start=179
  _globals['_METRIC']._serialized_end=983
  _globals['_NODE']._serialized_start=985
  _globals['_NODE']._serialized_end=1093
  _globals['_LINK']._serialized_start=1095
  _globals['_LINK']._serialized_end=1149
  _globals['_GETMETRICSRESPONSE']._serialized_start=1152
  _globals['_GETMETRICSRESPONSE']._serialized_end=1292
  _globals['_ROWLEVELMETRIC']._serialized_start=1295
  _globals['_ROWLEVELMETRIC']._serialized_end=1925
  _globals['_ROWLEVELMETRICCONFIGURATION']._serialized_start=1928
  _globals['_ROWLEVELMETRICCONFIGURATION']._serialized_end=2169
  _globals['_GETCUSTOMMETRICSDETAILSREQUEST']._serialized_start=2171
  _globals['_GETCUSTOMMETRICSDETAILSREQUEST']._serialized_end=2272
  _globals['_GETCUSTOMMETRICSDETAILSRESPONSE']._serialized_start=2275
  _globals['_GETCUSTOMMETRICSDETAILSRESPONSE']._serialized_end=2470
  _globals['_GETCUSTOMMETRICSDETAILSRESPONSE_SERIESENTRY']._serialized_start=2389
  _globals['_GETCUSTOMMETRICSDETAILSRESPONSE_SERIESENTRY']._serialized_end=2470
  _globals['_METRICSGROUP']._serialized_start=2472
  _globals['_METRICSGROUP']._serialized_end=2569
  _globals['_GETCUSTOMMETRICSREQUEST']._serialized_start=2571
  _globals['_GETCUSTOMMETRICSREQUEST']._serialized_end=2596
  _globals['_GETCUSTOMMETRICSRESPONSE']._serialized_start=2599
  _globals['_GETCUSTOMMETRICSRESPONSE']._serialized_end=2735
  _globals['_CREATECUSTOMMETRICREQUEST']._serialized_start=2738
  _globals['_CREATECUSTOMMETRICREQUEST']._serialized_end=2873
  _globals['_CREATECUSTOMMETRICRESPONSE']._serialized_start=2875
  _globals['_CREATECUSTOMMETRICRESPONSE']._serialized_end=2919
  _globals['_DELETECUSTOMMETRICREQUEST']._serialized_start=2921
  _globals['_DELETECUSTOMMETRICREQUEST']._serialized_end=2964
  _globals['_DELETECUSTOMMETRICRESPONSE']._serialized_start=2966
  _globals['_DELETECUSTOMMETRICRESPONSE']._serialized_end=2994
  _globals['_METRICSSERVICE']._serialized_start=2997
  _globals['_METRICSSERVICE']._serialized_end=3493
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Key(_message.Message):
    __slots__ = ("id", "cloud_region", "key_id", "key_arn", "active", "managed_by", "key_type", "name", "cloud_account_id", "created_at", "updated_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    CLOUD_REGION_FIELD_NUMBER: _ClassVar[int]
    KEY_ID_FIELD_NUMBER: _ClassVar[int]
    KEY_ARN_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    MANAGED_BY_FIELD_NUMBER: _ClassVar[int]
    KEY_TYPE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CLOUD_ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    cloud_region: str
    key_id: str
    key_arn: str
    active: bool
    managed_by: str
    key_type: str
    name: str
    cloud_account_id: str
    created_at: str
    updated_at: str
    def __init__(self, id: _Optional[str] = ..., cloud_region: _Optional[str] = ..., key_id: _Optional[str] = ..., key_arn: _Optional[str] = ..., active: bool = ..., managed_by: _Optional[str] = ..., key_type: _Optional[str] = ..., name: _Optional[str] = ..., cloud_account_id: _Optional[str] = ..., created_at: _Optional[str] = ..., updated_at: _Optional[str] = ...) -> None: ...



from .types.v1 import satellite_pb2 as _satellite_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateSatelliteRequest(_message.Message):
    __slots__ = ("name", "termination_protection")
    NAME_FIELD_NUMBER: _ClassVar[int]
    TERMINATION_PROTECTION_FIELD_NUMBER: _ClassVar[int]
    name: str
    termination_protection: bool
    def __init__(self, name: _Optional[str] = ..., termination_protection: bool = ...) -> None: ...

class CreateSatelliteResponse(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetSatelliteByIdRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetSatelliteByIdResponse(_message.Message):
    __slots__ = ("satellite",)
    SATELLITE_FIELD_NUMBER: _ClassVar[int]
    satellite: _satellite_pb2.Satellite
    def __init__(self, satellite: _Optional[_Union[_satellite_pb2.Satellite, _Mapping]] = ...) -> None: ...

class GetSatellitesRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetSatellitesResponse(_message.Message):
    __slots__ = ("satellites",)
    SATELLITES_FIELD_NUMBER: _ClassVar[int]
    satellites: _containers.RepeatedCompositeFieldContainer[_satellite_pb2.Satellite]
    def __init__(self, satellites: _Optional[_Iterable[_Union[_satellite_pb2.Satellite, _Mapping]]] = ...) -> None: ...

class GetSatelliteApiKeyRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetSatelliteApiKeyResponse(_message.Message):
    __slots__ = ("api_key",)
    API_KEY_FIELD_NUMBER: _ClassVar[int]
    api_key: str
    def __init__(self, api_key: _Optional[str] = ...) -> None: ...

class UpdateSatelliteRequest(_message.Message):
    __slots__ = ("id", "name", "termination_protection")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TERMINATION_PROTECTION_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    termination_protection: bool
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., termination_protection: bool = ...) -> None: ...

class UpdateSatelliteResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteSatelliteRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteSatelliteResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class SatelliteOnlineInstance(_message.Message):
    __slots__ = ("instance_id", "last_seen", "start_time", "version")
    INSTANCE_ID_FIELD_NUMBER: _ClassVar[int]
    LAST_SEEN_FIELD_NUMBER: _ClassVar[int]
    START_TIME_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    instance_id: str
    last_seen: _timestamp_pb2.Timestamp
    start_time: _timestamp_pb2.Timestamp
    version: str
    def __init__(self, instance_id: _Optional[str] = ..., last_seen: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., start_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., version: _Optional[str] = ...) -> None: ...

class GetOnlineInstancesBySatelliteIdRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetOnlineInstancesBySatelliteIdResponse(_message.Message):
    __slots__ = ("instances",)
    INSTANCES_FIELD_NUMBER: _ClassVar[int]
    instances: _containers.RepeatedCompositeFieldContainer[SatelliteOnlineInstance]
    def __init__(self, instances: _Optional[_Iterable[_Union[SatelliteOnlineInstance, _Mapping]]] = ...) -> None: ...



from .types.v1 import external_id_pb2 as _external_id_pb2
from .types.v1 import group_pb2 as _group_pb2
from .types.v1 import list_metadata_pb2 as _list_metadata_pb2
from .types.v1 import user_pb2 as _user_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from ...validate.v1 import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListGroupsRequest(_message.Message):
    __slots__ = ("limit", "cursor", "order", "search", "search_fields")
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    CURSOR_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    SEARCH_FIELD_NUMBER: _ClassVar[int]
    SEARCH_FIELDS_FIELD_NUMBER: _ClassVar[int]
    limit: int
    cursor: str
    order: str
    search: str
    search_fields: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, limit: _Optional[int] = ..., cursor: _Optional[str] = ..., order: _Optional[str] = ..., search: _Optional[str] = ..., search_fields: _Optional[_Iterable[str]] = ...) -> None: ...

class CreateGroupRequest(_message.Message):
    __slots__ = ("name", "description", "termination_protection")
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    TERMINATION_PROTECTION_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    termination_protection: bool
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ..., termination_protection: bool = ...) -> None: ...

class GetGroupByIdRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteGroupRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class UpdateGroupRequest(_message.Message):
    __slots__ = ("id", "name", "description", "termination_protection")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    TERMINATION_PROTECTION_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    termination_protection: bool
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., termination_protection: bool = ...) -> None: ...

class LinkUsersToGroupRequest(_message.Message):
    __slots__ = ("id", "user_ids")
    ID_FIELD_NUMBER: _ClassVar[int]
    USER_IDS_FIELD_NUMBER: _ClassVar[int]
    id: str
    user_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, id: _Optional[str] = ..., user_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class LinkUsersToGroupV2Request(_message.Message):
    __slots__ = ("id", "user_ids")
    ID_FIELD_NUMBER: _ClassVar[int]
    USER_IDS_FIELD_NUMBER: _ClassVar[int]
    id: str
    user_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, id: _Optional[str] = ..., user_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class UnlinkUsersFromGroupRequest(_message.Message):
    __slots__ = ("id", "user_ids")
    ID_FIELD_NUMBER: _ClassVar[int]
    USER_IDS_FIELD_NUMBER: _ClassVar[int]
    id: str
    user_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, id: _Optional[str] = ..., user_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class CreateGroupResponse(_message.Message):
    __slots__ = ("group",)
    GROUP_FIELD_NUMBER: _ClassVar[int]
    group: _group_pb2.Group
    def __init__(self, group: _Optional[_Union[_group_pb2.Group, _Mapping]] = ...) -> None: ...

class GetGroupByIdResponse(_message.Message):
    __slots__ = ("group",)
    GROUP_FIELD_NUMBER: _ClassVar[int]
    group: _group_pb2.Group
    def __init__(self, group: _Optional[_Union[_group_pb2.Group, _Mapping]] = ...) -> None: ...

class DeleteGroupResponse(_message.Message):
    __slots__ = ("group",)
    GROUP_FIELD_NUMBER: _ClassVar[int]
    group: _group_pb2.Group
    def __init__(self, group: _Optional[_Union[_group_pb2.Group, _Mapping]] = ...) -> None: ...

class UpdateGroupResponse(_message.Message):
    __slots__ = ("group",)
    GROUP_FIELD_NUMBER: _ClassVar[int]
    group: _group_pb2.Group
    def __init__(self, group: _Optional[_Union[_group_pb2.Group, _Mapping]] = ...) -> None: ...

class ListGroupsResponse(_message.Message):
    __slots__ = ("groups", "list_metadata")
    GROUPS_FIELD_NUMBER: _ClassVar[int]
    LIST_METADATA_FIELD_NUMBER: _ClassVar[int]
    groups: _containers.RepeatedCompositeFieldContainer[_group_pb2.Group]
    list_metadata: _list_metadata_pb2.ListMetadata
    def __init__(self, groups: _Optional[_Iterable[_Union[_group_pb2.Group, _Mapping]]] = ..., list_metadata: _Optional[_Union[_list_metadata_pb2.ListMetadata, _Mapping]] = ...) -> None: ...

class LinkUsersToGroupResponse(_message.Message):
    __slots__ = ("user_ids", "group_id")
    USER_IDS_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    user_ids: _containers.RepeatedScalarFieldContainer[str]
    group_id: str
    def __init__(self, user_ids: _Optional[_Iterable[str]] = ..., group_id: _Optional[str] = ...) -> None: ...

class LinkUsersToGroupV2Response(_message.Message):
    __slots__ = ("user_ids", "group_id")
    USER_IDS_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    user_ids: _containers.RepeatedScalarFieldContainer[str]
    group_id: str
    def __init__(self, user_ids: _Optional[_Iterable[str]] = ..., group_id: _Optional[str] = ...) -> None: ...

class UnlinkUsersFromGroupResponse(_message.Message):
    __slots__ = ("user_ids", "group_id")
    USER_IDS_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    user_ids: _containers.RepeatedScalarFieldContainer[str]
    group_id: str
    def __init__(self, user_ids: _Optional[_Iterable[str]] = ..., group_id: _Optional[str] = ...) -> None: ...

class UserLinkGroupResponse(_message.Message):
    __slots__ = ("user_ids", "group_id")
    USER_IDS_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    user_ids: _containers.RepeatedScalarFieldContainer[str]
    group_id: str
    def __init__(self, user_ids: _Optional[_Iterable[str]] = ..., group_id: _Optional[str] = ...) -> None: ...

class ListUsersRequest(_message.Message):
    __slots__ = ("limit", "cursor", "order", "search", "search_fields")
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    CURSOR_FIELD_NUMBER: _ClassVar[int]
    ORDER_FIELD_NUMBER: _ClassVar[int]
    SEARCH_FIELD_NUMBER: _ClassVar[int]
    SEARCH_FIELDS_FIELD_NUMBER: _ClassVar[int]
    limit: int
    cursor: str
    order: str
    search: str
    search_fields: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, limit: _Optional[int] = ..., cursor: _Optional[str] = ..., order: _Optional[str] = ..., search: _Optional[str] = ..., search_fields: _Optional[_Iterable[str]] = ...) -> None: ...

class ListUsersResponse(_message.Message):
    __slots__ = ("users", "list_metadata")
    USERS_FIELD_NUMBER: _ClassVar[int]
    LIST_METADATA_FIELD_NUMBER: _ClassVar[int]
    users: _containers.RepeatedCompositeFieldContainer[_user_pb2.User]
    list_metadata: _list_metadata_pb2.ListMetadata
    def __init__(self, users: _Optional[_Iterable[_Union[_user_pb2.User, _Mapping]]] = ..., list_metadata: _Optional[_Union[_list_metadata_pb2.ListMetadata, _Mapping]] = ...) -> None: ...

class CreateUserRequest(_message.Message):
    __slots__ = ("first_name", "last_name", "type", "app_type", "app_id", "name", "email", "admin", "idp", "status", "expire_at", "termination_protection")
    FIRST_NAME_FIELD_NUMBER: _ClassVar[int]
    LAST_NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    APP_TYPE_FIELD_NUMBER: _ClassVar[int]
    APP_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    ADMIN_FIELD_NUMBER: _ClassVar[int]
    IDP_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    EXPIRE_AT_FIELD_NUMBER: _ClassVar[int]
    TERMINATION_PROTECTION_FIELD_NUMBER: _ClassVar[int]
    first_name: str
    last_name: str
    type: str
    app_type: str
    app_id: str
    name: str
    email: str
    admin: bool
    idp: str
    status: str
    expire_at: _timestamp_pb2.Timestamp
    termination_protection: bool
    def __init__(self, first_name: _Optional[str] = ..., last_name: _Optional[str] = ..., type: _Optional[str] = ..., app_type: _Optional[str] = ..., app_id: _Optional[str] = ..., name: _Optional[str] = ..., email: _Optional[str] = ..., admin: bool = ..., idp: _Optional[str] = ..., status: _Optional[str] = ..., expire_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., termination_protection: bool = ...) -> None: ...

class CreateUserResponse(_message.Message):
    __slots__ = ("user", "tenant_id")
    USER_FIELD_NUMBER: _ClassVar[int]
    TENANT_ID_FIELD_NUMBER: _ClassVar[int]
    user: _user_pb2.User
    tenant_id: str
    def __init__(self, user: _Optional[_Union[_user_pb2.User, _Mapping]] = ..., tenant_id: _Optional[str] = ...) -> None: ...

class CreateUserV2Request(_message.Message):
    __slots__ = ("first_name", "last_name", "type", "app_type", "app_id", "name", "email", "admin", "idp", "status", "expire_at", "termination_protection")
    FIRST_NAME_FIELD_NUMBER: _ClassVar[int]
    LAST_NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    APP_TYPE_FIELD_NUMBER: _ClassVar[int]
    APP_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    ADMIN_FIELD_NUMBER: _ClassVar[int]
    IDP_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    EXPIRE_AT_FIELD_NUMBER: _ClassVar[int]
    TERMINATION_PROTECTION_FIELD_NUMBER: _ClassVar[int]
    first_name: str
    last_name: str
    type: str
    app_type: str
    app_id: str
    name: str
    email: str
    admin: bool
    idp: str
    status: str
    expire_at: _timestamp_pb2.Timestamp
    termination_protection: bool
    def __init__(self, first_name: _Optional[str] = ..., last_name: _Optional[str] = ..., type: _Optional[str] = ..., app_type: _Optional[str] = ..., app_id: _Optional[str] = ..., name: _Optional[str] = ..., email: _Optional[str] = ..., admin: bool = ..., idp: _Optional[str] = ..., status: _Optional[str] = ..., expire_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., termination_protection: bool = ...) -> None: ...

class CreateUserV2Response(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetUserByIdRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetUserByIdResponse(_message.Message):
    __slots__ = ("user",)
    USER_FIELD_NUMBER: _ClassVar[int]
    user: _user_pb2.User
    def __init__(self, user: _Optional[_Union[_user_pb2.User, _Mapping]] = ...) -> None: ...

class DeleteUserRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteUserResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class UpdateUserRequest(_message.Message):
    __slots__ = ("id", "name", "first_name", "last_name", "email", "termination_protection")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    FIRST_NAME_FIELD_NUMBER: _ClassVar[int]
    LAST_NAME_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    TERMINATION_PROTECTION_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    first_name: str
    last_name: str
    email: str
    termination_protection: bool
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., first_name: _Optional[str] = ..., last_name: _Optional[str] = ..., email: _Optional[str] = ..., termination_protection: bool = ...) -> None: ...

class UpdateUserResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetMachineUserAuthTokenRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetMachineUserAuthTokenResponse(_message.Message):
    __slots__ = ("token", "username")
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    token: str
    username: str
    def __init__(self, token: _Optional[str] = ..., username: _Optional[str] = ...) -> None: ...

class CreateHumanUserAuthTokenRequest(_message.Message):
    __slots__ = ("email",)
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    email: str
    def __init__(self, email: _Optional[str] = ...) -> None: ...

class CreateHumanUserAuthTokenResponse(_message.Message):
    __slots__ = ("token", "username", "expires_at")
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    token: str
    username: str
    expires_at: _timestamp_pb2.Timestamp
    def __init__(self, token: _Optional[str] = ..., username: _Optional[str] = ..., expires_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class RefreshMachineUserAuthTokenRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class RefreshMachineUserAuthTokenResponse(_message.Message):
    __slots__ = ("token", "username")
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    token: str
    username: str
    def __init__(self, token: _Optional[str] = ..., username: _Optional[str] = ...) -> None: ...

class GetUserExternalIdsRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetUserExternalIdsResponse(_message.Message):
    __slots__ = ("external_ids",)
    EXTERNAL_IDS_FIELD_NUMBER: _ClassVar[int]
    external_ids: _containers.RepeatedCompositeFieldContainer[_external_id_pb2.ExternalId]
    def __init__(self, external_ids: _Optional[_Iterable[_Union[_external_id_pb2.ExternalId, _Mapping]]] = ...) -> None: ...

class MapUserToExternalIdRequest(_message.Message):
    __slots__ = ("user_id", "external_id", "description", "app_id")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    APP_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    external_id: str
    description: str
    app_id: str
    def __init__(self, user_id: _Optional[str] = ..., external_id: _Optional[str] = ..., description: _Optional[str] = ..., app_id: _Optional[str] = ...) -> None: ...

class MapUserToExternalIdResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteExternalIdMappingRequest(_message.Message):
    __slots__ = ("mapping_id",)
    MAPPING_ID_FIELD_NUMBER: _ClassVar[int]
    mapping_id: str
    def __init__(self, mapping_id: _Optional[str] = ...) -> None: ...

class DeleteExternalIdMappingResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from . import external_id_pb2 as _external_id_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class User(_message.Message):
    __slots__ = ("id", "organization_id", "first_name", "last_name", "type", "app_type", "role", "name", "db_username", "email", "idp", "idp_user_id", "status", "expire_at", "created_at", "external_ids", "machine_role_access_token", "dsync_user_id", "app_id", "admin", "termination_protection")
    ID_FIELD_NUMBER: _ClassVar[int]
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    FIRST_NAME_FIELD_NUMBER: _ClassVar[int]
    LAST_NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    APP_TYPE_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DB_USERNAME_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    IDP_FIELD_NUMBER: _ClassVar[int]
    IDP_USER_ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    EXPIRE_AT_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_IDS_FIELD_NUMBER: _ClassVar[int]
    MACHINE_ROLE_ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    DSYNC_USER_ID_FIELD_NUMBER: _ClassVar[int]
    APP_ID_FIELD_NUMBER: _ClassVar[int]
    ADMIN_FIELD_NUMBER: _ClassVar[int]
    TERMINATION_PROTECTION_FIELD_NUMBER: _ClassVar[int]
    id: str
    organization_id: str
    first_name: str
    last_name: str
    type: str
    app_type: str
    role: str
    name: str
    db_username: str
    email: str
    idp: str
    idp_user_id: str
    status: str
    expire_at: _timestamp_pb2.Timestamp
    created_at: _timestamp_pb2.Timestamp
    external_ids: _containers.RepeatedCompositeFieldContainer[_external_id_pb2.ExternalId]
    machine_role_access_token: str
    dsync_user_id: str
    app_id: str
    admin: bool
    termination_protection: bool
    def __init__(self, id: _Optional[str] = ..., organization_id: _Optional[str] = ..., first_name: _Optional[str] = ..., last_name: _Optional[str] = ..., type: _Optional[str] = ..., app_type: _Optional[str] = ..., role: _Optional[str] = ..., name: _Optional[str] = ..., db_username: _Optional[str] = ..., email: _Optional[str] = ..., idp: _Optional[str] = ..., idp_user_id: _Optional[str] = ..., status: _Optional[str] = ..., expire_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., external_ids: _Optional[_Iterable[_Union[_external_id_pb2.ExternalId, _Mapping]]] = ..., machine_role_access_token: _Optional[str] = ..., dsync_user_id: _Optional[str] = ..., app_id: _Optional[str] = ..., admin: bool = ..., termination_protection: bool = ...) -> None: ...



import grpc


from .gen.admin.v1.integration_external_api_pb2 import (
	Auth,
	CreateExternalApiIntegrationRequest,
	CreateExternalApiIntegrationResponse,
	ApiIntegration,
	GetExternalApiIntegrationRequest,
	GetExternalApiIntegrationResponse,
	DeleteExternalApiIntegrationRequest,
	DeleteExternalApiIntegrationResponse,
	GetExternalApiIntegrationsRequest,
	GetExternalApiIntegrationsResponse,
)

from .gen.admin.v1.integration_external_api_pb2_grpc import ExternalApiServiceStub
class ExternalApiService:
	def __init__(self, base_url, token):
		self.base_url = base_url
		self.channel = grpc.secure_channel(self.base_url, grpc.ssl_channel_credentials())
		self.stub = ExternalApiServiceStub(self.channel)
		self.headers = [('x-api-key', token)]

	def CreateExternalApiIntegration(self, request: CreateExternalApiIntegrationRequest) -> CreateExternalApiIntegrationResponse:
		return self.stub.CreateExternalApiIntegration(request, metadata=self.headers)

	def GetExternalApiIntegration(self, request: GetExternalApiIntegrationRequest) -> GetExternalApiIntegrationResponse:
		return self.stub.GetExternalApiIntegration(request, metadata=self.headers)

	def DeleteExternalApiIntegration(self, request: DeleteExternalApiIntegrationRequest) -> DeleteExternalApiIntegrationResponse:
		return self.stub.DeleteExternalApiIntegration(request, metadata=self.headers)

	def GetExternalApiIntegrations(self, request: GetExternalApiIntegrationsRequest) -> GetExternalApiIntegrationsResponse:
		return self.stub.GetExternalApiIntegrations(request, metadata=self.headers)




import grpc


from .gen.admin.v1.integration_cloud_pb2 import (
	GetDataplaneByIdRequest,
	GetDataplaneByIdResponse,
	GetDataplaneRoutesByIdRequest,
	GetDataplaneRoutesByIdResponse,
	CreateAwsConnectionSessionRequest,
	CreateAwsConnectionSessionResponse,
	DeleteAwsConnectionSessionRequest,
	GetIntegrationsCloudAccountByIdRequest,
	GetIntegrationsCloudAccountByIdResponse,
	GetIntegrationsCloudAccountsRequest,
	GetIntegrationsCloudAccountsResponse,
	CreateGcpConnectionSessionRequest,
	CreateGcpConnectionSessionResponse,
	DeleteAwsConnectionSessionResponse,
	GetDataplaneStacksByCloudAccountIdRequest,
	GetDataplaneStacksByCloudAccountIdResponse,
)

from .gen.admin.v1.integration_cloud_pb2_grpc import CloudServiceStub
class CloudService:
	def __init__(self, base_url, token):
		self.base_url = base_url
		self.channel = grpc.secure_channel(self.base_url, grpc.ssl_channel_credentials())
		self.stub = CloudServiceStub(self.channel)
		self.headers = [('x-api-key', token)]

	def GetDataplaneById(self, request: GetDataplaneByIdRequest) -> GetDataplaneByIdResponse:
		return self.stub.GetDataplaneById(request, metadata=self.headers)

	def GetDataplaneRoutesById(self, request: GetDataplaneRoutesByIdRequest) -> GetDataplaneRoutesByIdResponse:
		return self.stub.GetDataplaneRoutesById(request, metadata=self.headers)

	def GetDataplaneStacksByCloudAccountId(self, request: GetDataplaneStacksByCloudAccountIdRequest) -> GetDataplaneStacksByCloudAccountIdResponse:
		return self.stub.GetDataplaneStacksByCloudAccountId(request, metadata=self.headers)

	def CreateAwsConnectionSession(self, request: CreateAwsConnectionSessionRequest) -> CreateAwsConnectionSessionResponse:
		return self.stub.CreateAwsConnectionSession(request, metadata=self.headers)

	def DeleteAwsConnectionSession(self, request: DeleteAwsConnectionSessionRequest) -> DeleteAwsConnectionSessionResponse:
		return self.stub.DeleteAwsConnectionSession(request, metadata=self.headers)

	def GetIntegrationsCloudAccountById(self, request: GetIntegrationsCloudAccountByIdRequest) -> GetIntegrationsCloudAccountByIdResponse:
		return self.stub.GetIntegrationsCloudAccountById(request, metadata=self.headers)

	def GetIntegrationsCloudAccounts(self, request: GetIntegrationsCloudAccountsRequest) -> GetIntegrationsCloudAccountsResponse:
		return self.stub.GetIntegrationsCloudAccounts(request, metadata=self.headers)

	def CreateGcpConnectionSession(self, request: CreateGcpConnectionSessionRequest) -> CreateGcpConnectionSessionResponse:
		return self.stub.CreateGcpConnectionSession(request, metadata=self.headers)




from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class LogLinkItem(_message.Message):
    __slots__ = ("id", "integration_log_id", "datastore_id")
    ID_FIELD_NUMBER: _ClassVar[int]
    INTEGRATION_LOG_ID_FIELD_NUMBER: _ClassVar[int]
    DATASTORE_ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    integration_log_id: str
    datastore_id: str
    def __init__(self, id: _Optional[str] = ..., integration_log_id: _Optional[str] = ..., datastore_id: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/registry.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/registry.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61\x64min/v1/registry.proto\x12\x08\x61\x64min.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xbf\x01\n\x0eOnlineInstance\x12\x1f\n\x0binstance_id\x18\x01 \x01(\tR\ninstanceId\x12\x37\n\tlast_seen\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08lastSeen\x12\x39\n\nstart_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartTime\x12\x18\n\x07version\x18\x04 \x01(\tR\x07version\"f\n\rOnlineSidecar\x12\x1d\n\nsidecar_id\x18\x01 \x01(\tR\tsidecarId\x12\x36\n\tinstances\x18\x02 \x03(\x0b\x32\x18.admin.v1.OnlineInstanceR\tinstances\"\"\n GetOnlineInstancesByOrgIdRequest\"\xd0\x01\n!GetOnlineInstancesByOrgIdResponse\x12U\n\x08sidecars\x18\x01 \x03(\x0b\x32\x39.admin.v1.GetOnlineInstancesByOrgIdResponse.SidecarsEntryR\x08sidecars\x1aT\n\rSidecarsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x17.admin.v1.OnlineSidecarR\x05value:\x02\x38\x01\"E\n$GetOnlineInstancesBySidecarIdRequest\x12\x1d\n\nsidecar_id\x18\x01 \x01(\tR\tsidecarId\"_\n%GetOnlineInstancesBySidecarIdResponse\x12\x36\n\tinstances\x18\x01 \x03(\x0b\x32\x18.admin.v1.OnlineInstanceR\tinstances2\x8e\x02\n\x0fRegistryService\x12v\n\x19GetOnlineInstancesByOrgId\x12*.admin.v1.GetOnlineInstancesByOrgIdRequest\x1a+.admin.v1.GetOnlineInstancesByOrgIdResponse\"\x00\x12\x82\x01\n\x1dGetOnlineInstancesBySidecarId\x12..admin.v1.GetOnlineInstancesBySidecarIdRequest\x1a/.admin.v1.GetOnlineInstancesBySidecarIdResponse\"\x00\x42\xa3\x01\n\x0c\x63om.admin.v1B\rRegistryProtoP\x01ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.registry_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\rRegistryProtoP\001ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_GETONLINEINSTANCESBYORGIDRESPONSE_SIDECARSENTRY']._loaded_options = None
  _globals['_GETONLINEINSTANCESBYORGIDRESPONSE_SIDECARSENTRY']._serialized_options = b'8\001'
  _globals['_ONLINEINSTANCE']._serialized_start=71
  _globals['_ONLINEINSTANCE']._serialized_end=262
  _globals['_ONLINESIDECAR']._serialized_start=264
  _globals['_ONLINESIDECAR']._serialized_end=366
  _globals['_GETONLINEINSTANCESBYORGIDREQUEST']._serialized_start=368
  _globals['_GETONLINEINSTANCESBYORGIDREQUEST']._serialized_end=402
  _globals['_GETONLINEINSTANCESBYORGIDRESPONSE']._serialized_start=405
  _globals['_GETONLINEINSTANCESBYORGIDRESPONSE']._serialized_end=613
  _globals['_GETONLINEINSTANCESBYORGIDRESPONSE_SIDECARSENTRY']._serialized_start=529
  _globals['_GETONLINEINSTANCESBYORGIDRESPONSE_SIDECARSENTRY']._serialized_end=613
  _globals['_GETONLINEINSTANCESBYSIDECARIDREQUEST']._serialized_start=615
  _globals['_GETONLINEINSTANCESBYSIDECARIDREQUEST']._serialized_end=684
  _globals['_GETONLINEINSTANCESBYSIDECARIDRESPONSE']._serialized_start=686
  _globals['_GETONLINEINSTANCESBYSIDECARIDRESPONSE']._serialized_end=781
  _globals['_REGISTRYSERVICE']._serialized_start=784
  _globals['_REGISTRYSERVICE']._serialized_end=1054
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class IntegrationApp(_message.Message):
    __slots__ = ("id", "name", "type", "created_at", "metabase_hostname", "metabase_username", "metabase_password", "linked_db_user_id", "fivetran_api_key", "fivetran_api_secret")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    METABASE_HOSTNAME_FIELD_NUMBER: _ClassVar[int]
    METABASE_USERNAME_FIELD_NUMBER: _ClassVar[int]
    METABASE_PASSWORD_FIELD_NUMBER: _ClassVar[int]
    LINKED_DB_USER_ID_FIELD_NUMBER: _ClassVar[int]
    FIVETRAN_API_KEY_FIELD_NUMBER: _ClassVar[int]
    FIVETRAN_API_SECRET_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    type: str
    created_at: int
    metabase_hostname: str
    metabase_username: str
    metabase_password: str
    linked_db_user_id: str
    fivetran_api_key: str
    fivetran_api_secret: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., type: _Optional[str] = ..., created_at: _Optional[int] = ..., metabase_hostname: _Optional[str] = ..., metabase_username: _Optional[str] = ..., metabase_password: _Optional[str] = ..., linked_db_user_id: _Optional[str] = ..., fivetran_api_key: _Optional[str] = ..., fivetran_api_secret: _Optional[str] = ...) -> None: ...
